EchoPort class

Test harnass stub for UsbPort. Sends the data back with a delay.

Inheritance

Constructors

EchoPort({Duration writeDelay = const Duration(seconds: 0)})

Properties

hashCode → int
The hash code for this object.
no setterinherited
inputStream → Stream<Uint8List>?
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
writeDelay → Duration
final

Methods

close() → void
fakeData() → Stream<Uint8List>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
write(Uint8List data) → Future<void>
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited